@@ -15,15 +15,26 @@
    along with fplll. If not, see <http://www.gnu.org/licenses/>. */
 
 #include "enumerate_ext.h"
+#include <fplll/defs.h>
+
+#if FPLLL_MAX_PARALLEL_ENUM_DIM != 0
+#include "../enum-parallel/enumlib.h"
+#endif
 
 FPLLL_BEGIN_NAMESPACE
 
 // set & get external enumerator (nullptr => disabled)
+#if FPLLL_MAX_PARALLEL_ENUM_DIM != 0
+std::function<extenum_fc_enumerate> fplll_extenum = enumlib::enumlib_enumerate;
+#else
 std::function<extenum_fc_enumerate> fplll_extenum = nullptr;
+#endif
+
 void set_external_enumerator(std::function<extenum_fc_enumerate> extenum)
 {
   fplll_extenum = extenum;
 }
+
 std::function<extenum_fc_enumerate> get_external_enumerator() { return fplll_extenum; }
 
 template <typename ZT, typename FT>
@@ -73,9 +84,11 @@ template <typename ZT, typename FT>
 void ExternalEnumeration<ZT, FT>::callback_set_config(enumf *mu, size_t mudim, bool mutranspose,
                                                       enumf *rdiag, enumf *pruning)
 {
+
   FT fr, fmu;
   long rexpo;
-
+  // Copy over the squared norms for the Gram-Schmidt vectors.
+  // Note that these norms are normalised.
   for (int i = 0; i < _d; ++i)
   {
     fr = _gso.get_r_exp(i + _first, i + _first, rexpo);
@@ -83,12 +96,14 @@ void ExternalEnumeration<ZT, FT>::callback_set_config(enumf *mu, size_t mudim, b
     rdiag[i] = fr.get_d();
   }
 
+  // Now we copy the mu values from the gso matrix.
   if (mutranspose)
   {
+
     size_t offs = 0;
     for (int i = 0; i < _d; ++i, offs += mudim)
     {
-      for (int j = 0; j < _d; ++j)
+      for (int j = i + 1; j < _d; ++j)
       {
         _gso.get_mu(fmu, j + _first, i + _first);
         /* mu[i][j]= */
@@ -110,14 +125,16 @@ void ExternalEnumeration<ZT, FT>::callback_set_config(enumf *mu, size_t mudim, b
     }
   }
 
+  // if there's no pruning enabled then we just fill pruning with 1s
   if (_pruning.empty())
   {
-    for (int i   = 0; i < _d; ++i)
+    for (int i = 0; i < _d; ++i)
       pruning[i] = 1.0;
   }
   else
   {
-    for (int i   = 0; i < _d; ++i)
+    // Otherwise we just copy over the pruning parameters
+    for (int i = 0; i < _d; ++i)
       pruning[i] = _pruning[i];
   }
 }
@@ -126,7 +143,7 @@ template <typename ZT, typename FT>
 enumf ExternalEnumeration<ZT, FT>::callback_process_sol(enumf dist, enumf *sol)
 {
   for (int i = 0; i < _d; ++i)
-    _fx[i]   = sol[i];
+    _fx[i] = sol[i];
   _evaluator.eval_sol(_fx, dist, _maxdist);
   return _maxdist;
 }
@@ -135,9 +152,9 @@ template <typename ZT, typename FT>
 void ExternalEnumeration<ZT, FT>::callback_process_subsol(enumf dist, enumf *subsol, int offset)
 {
   for (int i = 0; i < offset; ++i)
-    _fx[i]   = 0.0;
+    _fx[i] = 0.0;
   for (int i = offset; i < _d; ++i)
-    _fx[i]   = subsol[i];
+    _fx[i] = subsol[i];
   _evaluator.eval_sub_sol(offset, _fx, dist);
 }
 
