@@ -55,7 +55,7 @@ static int compute_min_prec(double &rho, int d, double delta, double eta, double
     // eta - 0.5 is an exact fp operation
     if (f_epsilon > eta - 0.5)
       f_epsilon = eta - 0.5;
-    tmp1        = 1.0;
+    tmp1 = 1.0;
     tmp1.sub(tmp1, f_delta, GMP_RNDD);
     if (f_epsilon > tmp1)
       f_epsilon = tmp1;
@@ -105,6 +105,100 @@ int l2_min_prec(int d, double delta, double eta, double epsilon)
   return compute_min_prec(rho, d, delta, eta, epsilon, MINPREC_L2);
 }
 
+int hlll_min_prec(int d_i, int n_i, double delta_d, double eta_d, double theta_d, double c_d)
+{
+  FPLLL_CHECK(delta_d < 1.0 && delta_d >= 0.25, "delta must be in [1/4, 1).");
+  FPLLL_CHECK(theta_d >= 0.0, "theta must be positive.");
+  FPLLL_CHECK(eta_d >= 0.5, "theta must be larger than or equal to 0.5.");
+  FPLLL_CHECK(eta_d - theta_d > 0.5, "eta - theta must be larger than 0.5.");
+
+  int old_prec = FP_NR<mpfr_t>::set_prec(53);
+  FP_NR<mpfr_t> d, n, delta, eta, theta, c, alpha, c0, c1, rho, phi, p0, p;
+  FP_NR<mpfr_t> ftmp0, ftmp1, ftmp2, ftmp3, ftmp4;
+
+  d     = d_i;
+  n     = n_i;
+  delta = delta_d;
+  eta   = eta_d;
+  theta = theta_d;
+  c     = c_d;
+
+  // ftmp0 = (1 + theta^2) * delta - eta^2
+  ftmp0 = (1.0 + theta * theta) * delta - eta * eta;
+  // ftmp0 = sqrt((1 + theta^2) * delta - eta^2)
+  ftmp0.sqrt(ftmp0);
+
+  // alpha = theta * eta + sqrt((1 + theta^2) * delta - eta^2) / (delta - eta^2)
+  alpha = (theta * eta + ftmp0) / (delta - eta * eta);
+
+  // ftmp0 = 3 / 2
+  ftmp0 = 3.0 / 2.0;
+  // ftmp0 = sqrt(3 / 2)
+  ftmp0.sqrt(ftmp0);
+  // ftmp1 = 1 - eta - theta
+  ftmp1 = 1.0 - eta - theta;
+  // ftmp1 = |1 - eta - theta|
+  ftmp1.abs(ftmp1);
+  ftmp2 = 6.0;
+  // ftmp2 = sqrt(6)
+  ftmp2.sqrt(ftmp2);
+  // ftmp3 = 1 + d * eta^2
+  ftmp3 = 1.0 + d * eta * eta;
+  // ftmp3 = sqrt(1 + d * eta^2)
+  ftmp3.sqrt(ftmp3);
+  // ftmp4 = sqrt(d)
+  ftmp4.sqrt(d);
+  // ftmp0 = 1 + |1 - eta - theta| * alpha / ((eta + theta) * (-1 + sqrt(3/2)))
+  ftmp0 = (1.0 + ftmp1 * alpha) / ((eta + theta) * (-1.0 + ftmp0));
+  // ftmp1 = 4 * sqrt(6) / (1 + eta) * sqrt(1 + d * eta^2)
+  ftmp1 = 4.0 * ftmp2 / (1.0 + eta) * ftmp3;
+  // ftmp0 = max(1 + |1 - eta - theta| * alpha / ((eta + theta) * (-1 + sqrt(3/2))),
+  //             4 * sqrt(6) / (1 + eta) * sqrt(1 + d * eta^2))
+  ftmp0.max_f(ftmp1);
+  // c0 = max(...) * n * sqrt(d)
+  c0 = ftmp0 * n * ftmp4;
+
+  // c1 = 8 * d * (n + 9) * c0
+  c1 = 8.0 * d * (n + 9.0) * c0;
+
+  // rho = (1 + eta + theta) * alpha
+  rho = (1.0 + eta + theta) * alpha;
+
+  // ftmp0 = rho^(d + 1) (since we want to compute phi(d))
+  ftmp0.pow_si(rho, d_i + 1);
+  // phi(d) = c1 * (1 + 1 / theta) * ftmp0
+  phi = c1 * (1.0 + 1.0 / theta) * ftmp0;
+
+  // ftmp0 = alpha^d
+  ftmp0.pow_si(alpha, d_i);
+  // ftmp0 = log(d^3 * phi(d) * alpha^d / theta)
+  ftmp0.log(d * d * d * phi * ftmp0 / theta);
+  // ftmp1 = log(2)
+  ftmp1.log(2);
+  // ftmp0 = log(d^3 * phi(d) * alpha^d / theta) / log(2)
+  ftmp0 = ftmp0 / ftmp1;
+  // p0 = log2(d^3 * phi(d) * alpha^d / theta) + 16 + c * d / 2
+  p0 = ftmp0 + 16.0 + c * d / 2.0;
+
+  // ftmp0 = log(1 - delta)
+  ftmp0.log(1.0 - delta);
+  // ftmp0 = log(1 - delta) / log(2)
+  ftmp0 = ftmp0 / ftmp1;
+  // ftmp2 = log(eta - theta - 1/2)
+  ftmp2.log(eta - theta - 0.5);
+  // ftmp2 = log(eta - theta - 1/2) / log(2)
+  ftmp2 = ftmp2 / ftmp1;
+  // p = p0 + 1 - log2(1 - delta) - log2(eta - theta - 1 / 2)
+  p = p0 + 1.0 - ftmp0 - ftmp2;
+
+  // Convert p in int
+  int p_i = static_cast<int>(ceil(p.get_d(GMP_RNDU)));
+
+  FP_NR<mpfr_t>::set_prec(old_prec);
+
+  return p_i;
+}
+
 /**
  * Computes the volume of a d-dimensional hypersphere of radius 1.
  */
