@@ -1,4 +1,5 @@
 /* Copyright (C) 2015 Martin Albrecht
+   Copyright (C) 2019 Koen de Boer & Wessel van Woerden
 
    This file is part of fplll. fplll is free software: you
    can redistribute it and/or modify it under the terms of the GNU Lesser
@@ -179,7 +180,7 @@ template <class ZT, class FT> int test_filename(const char *input_filename)
 {
   ZZ_mat<ZT> A;
   int status = 0;
-  status |= read_matrix(A, input_filename);
+  status |= read_file(A, input_filename);
   status |= test_lll<ZT, FT>(A);
   return status;
 }
